==> ifrit_3.0.0.orig.tar.gz: ifrit-3.0.0/core/iruler.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef IRULER_H
#define IRULER_H


#include <vtkAxisActor2D.h>
#include "ioverlaybase.h"
#include "iviewmodulecomponent.h"


class iColor;


class iRuler: public vtkAxisActor2D, protected iOverlayBase, protected iViewModuleComponent
{
	
public:
	
	static iRuler* New(iViewModule *vm);
	
	virtual int RenderOverlay(vtkViewport*);
	virtual int RenderOpaqueGeometry(vtkViewport*);
	virtual int RenderTranslucentGeometry(vtkViewport *){ return 0; }
	
	virtual void ReleaseGraphicsResources(vtkWindow *win);

	void SetColor(iColor &c);
	void SetBaseScale(float s);

	void SetScale(float s);
	inline float GetScale() const { return mScale; }

	void SetFontSize(int s);
	inline int GetFontSize() const { return mFontSize; }

protected:
	
	iRuler(iViewModule *vm);
	virtual ~iRuler();
	
private:

	float mLineWidth;
	int mTickLength;
	int mFontSize;
	float mDx;

	bool mStarted;
	float mScale, mBaseScale;
};

#endif // IRULER_H

==> ifrit_3.0.5.orig.tar.gz: ifrit-3.0.5/core/iruler.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2006 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef IRULER_H
#define IRULER_H


#include <vtkAxisActor2D.h>
#include "ioverlaybase.h"
#include "iviewmodulecomponent.h"


class iColor;


class iRuler: public vtkAxisActor2D, public iOverlayBase, protected iViewModuleComponent
{
	
public:
	
	static iRuler* New(iViewModule *vm);
	
	virtual int RenderOverlay(vtkViewport*);
	virtual int RenderOpaqueGeometry(vtkViewport*);
	virtual int RenderTranslucentGeometry(vtkViewport *){ return 0; }
	
	virtual void ReleaseGraphicsResources(vtkWindow *win);

	void SetColor(iColor &c);
	void SetBaseScale(float s);

	void SetScale(float s);
	inline float GetScale() const { return mScale; }

protected:
	
	iRuler(iViewModule *vm);
	virtual ~iRuler();
	
private:

	float mLineWidth;
	int mTickLength;
	float mDx;

	bool mStarted;
	float mScale, mBaseScale;
};

#endif // IRULER_H
